@@ -507,14 +507,15 @@ class AdaptiveTransferSpeed(FileTransferSpeed, SamplesMixin):
         return FileTransferSpeed.__call__(self, progress, data, value, elapsed)
 
 
-class AnimatedMarker(WidgetBase):
+class AnimatedMarker(TimeSensitiveWidgetBase):
     '''An animated marker for the progress bar which defaults to appear as if
     it were rotating.
     '''
 
-    def __init__(self, markers='|/-\\', default=None, **kwargs):
+    def __init__(self, markers='|/-\\', default=None, fill='', **kwargs):
         self.markers = markers
         self.default = default or markers[0]
+        self.fill = create_marker(fill) if fill else None
         WidgetBase.__init__(self, **kwargs)
 
     def __call__(self, progress, data, width=None):
@@ -524,7 +525,23 @@ class AnimatedMarker(WidgetBase):
         if progress.end_time:
             return self.default
 
-        return self.markers[data['updates'] % len(self.markers)]
+        if self.fill:
+            # Cut the last character so we can replace it with our marker
+            fill = self.fill(progress, data, width)[:-1]
+        else:
+            fill = ''
+
+        marker = self.markers[data['updates'] % len(self.markers)]
+
+        # Python 3 returns an int when indexing bytes
+        if isinstance(marker, int):  # pragma: no cover
+            marker = bytes(marker)
+            fill = fill.encode()
+        else:
+            # cast fill to the same type as marker
+            fill = type(marker)(fill)
+
+        return fill + marker
 
 
 # Alias for backwards compatibility
@@ -637,7 +654,6 @@ class Bar(AutoWidthWidgetBase):
         width -= progress.custom_len(left) + progress.custom_len(right)
         marker = converters.to_unicode(self.marker(progress, data, width))
         fill = converters.to_unicode(self.fill(progress, data, width))
-
         if self.fill_left:
             marker = marker.ljust(width, fill)
         else:
